package ru.ifmo.vizi.dmkm;

import ru.ifmo.vizi.base.Configuration;
import ru.ifmo.vizi.base.widgets.ShapeStyle;
import ru.ifmo.vizi.dmkm.ui.Button;
import ru.ifmo.vizi.dmkm.widgets.Vertex;

import java.awt.*;

/**
 * The instance of this class provides user to change the arc's capacity.
 * @author Yuri Bedny
 * @version 0.0
 */

public class EditMenu extends Container {

    private int i, j;

    private Vertex circle;

    /**
     * Menu buttons.
     */
    private Button plus;
    private Button delete;
    private Button minus;

    /**
     * Creates menu, which uses for changing arc's capacity.
     * @param config vis configuration.
     * @param editor net editor.
     */
    public EditMenu(Configuration config, final NetEditor editor) {

        plus = new Button(ShapeStyle.loadStyleSet(config, "menu-plus")) {
            protected void click() {
                editor.changeArc(i, j, 1);
            }
        };
        plus.setMessage(config.getParameter("menu-plus-message"));

        delete = new Button(ShapeStyle.loadStyleSet(config, "menu-delete")) {
            protected void click() {
                editor.deleteArc(i, j);
            }
        };
        delete.setMessage(config.getParameter("menu-delete-message"));

        minus = new Button(ShapeStyle.loadStyleSet(config, "menu-minus")) {
            protected void click() {
                editor.changeArc(i, j, -1);
            }
        };

        setLayout(new BorderLayout());
        add(plus, BorderLayout.NORTH);
        add(delete);
        add(minus);
        minus.setMessage(config.getParameter("menu-minus-message"));
    }

    /**
     * Sets arc which capacity is changing.
     * @param i the number of the startPoint vertex.
     * @param j the number of the secondPoint vertex.
     */
    public void setArc(int i, int j) {
        this.i = i;
        this.j = j;
    }

    /**
     * Resizes the buttons.
     */
    public void resizeButtons() {
        int width = getSize().width;
        int height = getSize().height - 1;
        plus.setSize(width, height / 3);
        delete.setSize(width, height / 3);
        minus.setSize(width, height / 3);
        plus.adjustFontSize();
        minus.adjustFontSize();
        delete.adjustFontSize();
        plus.setLocation(0, 0);
        delete.setLocation(0, plus.getLocation().y + plus.getSize().height);
        minus.setLocation(0, delete.getLocation().y + delete.getSize().height);
    }

    /**
     * Sets plus button to enabled state.
     * @param enabled
     */
    public void setPlusEnabled(boolean enabled) {
        plus.setEnabled(enabled);
    }

    /**
     * Sets minus button to enabled state.
     * @param enabled
     */
    public void setMinusEnabled(boolean enabled) {
        minus.setEnabled(enabled);
    }

    /**
     * Sets the  circle.
     * @param cir circle to set.
     */
    public void setCircle(Vertex cir) {
        this.circle = cir;
    }

    /**
     * Gets the circle.
     * @return the circle.
     */
    public Vertex getCircle() {
        return circle;
    }
}
