package ru.ifmo.vizi.dmkm.widgets;

import ru.ifmo.vizi.base.widgets.ShapeStyle;
import ru.ifmo.vizi.base.widgets.Ellipse;

import java.awt.*;
import java.awt.event.MouseEvent;

/**
 * Round shape.
 * @author Yuri Bedny
 * @version 0.0
 */

public class Vertex extends Ellipse {

    /**
     * Diameter of the vertex.
     */
    private int diam;

    /**
     * Vertices of the arc.
     */
    private int v1;
    private int v2;

    /**
     * Returns the thirst vertex for current arc's circle.
     * @return the thirst vertex for current arc's circle.
     */
    public int getV1() {
        return v1;
    }

    /**
     * Returns the secondPoint vertex for current arc's circle.
     * @return the secondPoint vertex for current arc's circle.
     */
    public int getV2() {
        return v2;
    }

    /**
     * Creates a new circle with specifed style set, diameter, message and vertices.
     * @param styleSet shape's style set.
     * @param diam vertex diameter.
     * @param message message to show.
     * @param v1 the startPoint arc's vertex.
     * @param v2 the secondPoint arc's vertex.
     */
    public Vertex(ShapeStyle[] styleSet, int diam, String message, int v1, int v2) {
        this(styleSet, diam, message);
        this.v1 = v1;
        this.v2 = v2;
    }

    /**
     * Creates a new circle with specified style set and diameter.
     * @param styleSet shape's style set.
     * @param diam vertex diameter.
     */
    public Vertex(ShapeStyle[] styleSet, int diam) {
        this(styleSet, diam, "");
    }

    /**
     *
     * @param styleSet shape's style set.
     * @param diam vertex diameter.
     * @param message message to show.
     */
    public Vertex(ShapeStyle[] styleSet, int diam, String message) {
        super(styleSet, message);
        diam = (diam * 2 + 1) / 2;
        setSize(diam, diam);
        this.diam = diam;
    }

    /**
     * Returns minimum shape size to contain message with specified size.
     * @param size message size.
     * @return minimum shape size.
     */
    protected Dimension fit(Dimension size) {
        return new Dimension(
                (int)Math.round(size.width * 1.3),
                (int)Math.round(size.height * 1.3)
        );
    }

    /**
     * Returns the center of the circle.
     * @return the center of the circle.
     */
    public Point getCenter() {
        return new Point(getLocation().x + Math.round(getSize().height / 2), getLocation().y + Math.round(getSize().width / 2));
    }


    public int getRadius() {
        return diam / 2;
    }

    //  
    public int getDiameter() {
        return diam;
    }

    /**
     * Distance between to points.
     * @param p1 the first point.
     * @param p2 the second point.
     * @return distance between to points.
     */
    private double dist(Point p1, Point p2) {
        double dx = p2.x - p1.x;
        double dy = p2.y - p1.y;
        return Math.sqrt(dx * dx + dy * dy);
    }

    public void processMouseMotionEvent(MouseEvent me) {
        Point p = new Point();
        p.x = diam / 2;
        p.y = diam / 2;
        if (dist(me.getPoint(), p) < diam / 2)
            super.processMouseMotionEvent(me);
    }

}
